pub struct FileLock { /* private fields */ }Expand description
An exclusive file lock (RAII guard).
The lock is released when this value is dropped (the underlying file descriptor / handle is closed, which releases the lock).
Implementations
Sourceimpl FileLock
impl FileLock
Sourcepub fn acquire(path: &Path) -> Result<Self>
pub fn acquire(path: &Path) -> Result<Self>
Acquire an exclusive lock on path, blocking until available.
If the lock file does not exist, it is created.
Sourcepub fn try_acquire(path: &Path) -> Result<Option<Self>>
pub fn try_acquire(path: &Path) -> Result<Option<Self>>
Try to acquire an exclusive lock without blocking.
Returns Ok(None) if the lock is held by another process.