pub struct SpawnConfigBuilder { /* private fields */ }Expand description
Builder for SpawnConfig with fluent setter methods for optional fields.
Implementations
Sourceimpl SpawnConfigBuilder
impl SpawnConfigBuilder
Sourcepub fn cwd(self, cwd: impl Into<PathBuf>) -> Self
pub fn cwd(self, cwd: impl Into<PathBuf>) -> Self
Set the working directory for the agent process.
Sourcepub fn allowed_tools(self, tools: Vec<String>) -> Self
pub fn allowed_tools(self, tools: Vec<String>) -> Self
Set the tools the agent is allowed to use.
Sourcepub fn permission_mode(self, mode: impl Into<String>) -> Self
pub fn permission_mode(self, mode: impl Into<String>) -> Self
Set the permission mode (e.g., "default", "plan", "bypassPermissions").
Sourcepub fn reasoning_effort(self, effort: impl Into<String>) -> Self
pub fn reasoning_effort(self, effort: impl Into<String>) -> Self
Set the reasoning effort level.
Sourcepub fn env_var(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn env_var(self, key: impl Into<String>, value: impl Into<String>) -> Self
Add a single environment variable.
Sourcepub fn memory(self, config: MemoryConfig) -> Self
pub fn memory(self, config: MemoryConfig) -> Self
Set memory configuration for cross-turn context injection.
Sourcepub fn delegate(self, delegation: CliDelegation) -> Self
pub fn delegate(self, delegation: CliDelegation) -> Self
Add a CLI delegation for this agent.
The agent’s prompt will be augmented with instructions on how and when to invoke the delegated CLI tool via Bash.
use agent_teams::backend::delegation::CliDelegation;
use agent_teams::SpawnConfig;
let config = SpawnConfig::builder("coder", "You write Rust code.")
.delegate(CliDelegation::codex())
.delegate(CliDelegation::gemini("gemini-2.5-pro"))
.build();
assert_eq!(config.delegations.len(), 2);Sourcepub fn build(self) -> SpawnConfig
pub fn build(self) -> SpawnConfig
Build the SpawnConfig.